body{-webkit-font-smoothing:antialiased;-moz-osx-font-smoothing:grayscale;font-family:-apple-system,BlinkMacSystemFont,Segoe UI,Roboto,Oxygen,Ubuntu,Cantarell,Fira Sans,Droid Sans,Helvetica Neue,sans-serif;margin:0}code{font-family:source-code-pro,Menlo,Monaco,Consolas,Courier New,monospace}@font-face{font-display:swap;font-family:Roboto;font-style:normal;font-weight:400;src:url(/static/media/roboto-cyrillic-ext-400-normal.493afe7ae8ecfe268800.woff2) format("woff2"),url(/static/media/roboto-all-400-normal.376ea5d93f71583052f6.woff) format("woff");unicode-range:U+0460-052f,U+1c80-1c88,U+20b4,U+2de0-2dff,U+a640-a69f,U+fe2e-fe2f}@font-face{font-display:swap;font-family:Roboto;font-style:normal;font-weight:400;src:url(/static/media/roboto-cyrillic-400-normal.5e493812deabd1d01e60.woff2) format("woff2"),url(/static/media/roboto-all-400-normal.376ea5d93f71583052f6.woff) format("woff");unicode-range:U+0400-045f,U+0490-0491,U+04b0-04b1,U+2116}@font-face{font-display:swap;font-family:Roboto;font-style:normal;font-weight:400;src:url(/static/media/roboto-greek-ext-400-normal.e769aa77798cffeb5842.woff2) format("woff2"),url(/static/media/roboto-all-400-normal.376ea5d93f71583052f6.woff) format("woff");unicode-range:U+1f??}@font-face{font-display:swap;font-family:Roboto;font-style:normal;font-weight:400;src:url(/static/media/roboto-greek-400-normal.1cbfc636c911faa4d0ca.woff2) format("woff2"),url(/static/media/roboto-all-400-normal.376ea5d93f71583052f6.woff) format("woff");unicode-range:U+0370-03ff}@font-face{font-display:swap;font-family:Roboto;font-style:normal;font-weight:400;src:url(/static/media/roboto-vietnamese-400-normal.c0bec65d01f776c00c91.woff2) format("woff2"),url(/static/media/roboto-all-400-normal.376ea5d93f71583052f6.woff) format("woff");unicode-range:U+0102-0103,U+0110-0111,U+0128-0129,U+0168-0169,U+01a0-01a1,U+01af-01b0,U+1ea0-1ef9,U+20ab}@font-face{font-display:swap;font-family:Roboto;font-style:normal;font-weight:400;src:url(/static/media/roboto-latin-ext-400-normal.c3dcdbd5bb4d4af80817.woff2) format("woff2"),url(/static/media/roboto-all-400-normal.376ea5d93f71583052f6.woff) format("woff");unicode-range:U+0100-024f,U+0259,U+1e??,U+2020,U+20a0-20ab,U+20ad-20cf,U+2113,U+2c60-2c7f,U+a720-a7ff}@font-face{font-display:swap;font-family:Roboto;font-style:normal;font-weight:400;src:url(/static/media/roboto-latin-400-normal.4673b4537a84c7f7a130.woff2) format("woff2"),url(/static/media/roboto-all-400-normal.376ea5d93f71583052f6.woff) format("woff");unicode-range:U+00??,U+0131,U+0152-0153,U+02bb-02bc,U+02c6,U+02da,U+02dc,U+2000-206f,U+2074,U+20ac,U+2122,U+2191,U+2193,U+2212,U+2215,U+feff,U+fffd}.auth-main{background-color:#eaeaea;height:100vh}.auth-content{left:50%;padding:10vmin;position:fixed;text-align:center;top:50%;-webkit-transform:translate(-50%,-50%);transform:translate(-50%,-50%)}.auth-card{background-color:#fff;border-radius:4px;box-shadow:3px 3px 8px #888;min-width:300px;padding:20px;text-align:center;width:400px}.auth-logo{margin-bottom:-10px;width:200px}.auth-form{margin-top:35px}.auth-input-field{font-size:18px;margin-bottom:25px}body,html{height:100%;margin:0}.base-page{background-color:#eaeaea;display:flex;flex-direction:column;flex-grow:1;min-height:calc(100vh - 40px);padding:20px}.base-container{background-color:#eaeaea;padding:10px}.network-header{padding-bottom:0!important;padding-top:5px!important}.network-detail{padding-bottom:5px!important;padding-top:0!important}
/*# sourceMappingURL=main.995087b4.css.map*/